# Pyre
Pyre is a performant type checker for python.

*Read this in other languages: [Español](README.es.md)*

[![Build Status](https://travis-ci.com/facebook/pyre-check.svg?branch=master)](https://travis-ci.com/facebook/pyre-check)

## Getting Started

To install Pyre on your system run `pip install pyre-check` and you should be good to go! Run it on your project with `pyre --source-directory . check`.

For more detailed documentation, see https://pyre-check.org.

## Supported platforms

* **Python**: you need **Python 3.5 or later** to run Pyre.

| :warning: NOTE: The minimum Python version will be switched to 3.6 around January-February 2020. |
| --- |

* **Operating System**:
  * a recent version of Linux (we tested on **Ubuntu 16.04 LTS** and **CentOS 7**);
  * **OSX 10.11** or newer;
  * please note: Windows is not supported.

## Installation

See [INSTALL.md](INSTALL.md) for details on installing Pyre from a packaged version or from source.

## Join the Pyre community

See [CONTRIBUTING.md](CONTRIBUTING.md) for how to help out.

## License

Pyre is licensed under the MIT license.
